/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/mozilla-central-linux-xulrunner/build/dom/interfaces/css/nsIDOMSVGCSS2Properties.idl
 */

#ifndef __gen_nsIDOMSVGCSS2Properties_h__
#define __gen_nsIDOMSVGCSS2Properties_h__


#ifndef __gen_nsIDOMCSS2Properties_h__
#include "nsIDOMCSS2Properties.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMSVGCSS2Properties */
#define NS_IDOMSVGCSS2PROPERTIES_IID_STR "b555e226-a387-4953-b2bc-c77296d146ec"

#define NS_IDOMSVGCSS2PROPERTIES_IID \
  {0xb555e226, 0xa387, 0x4953, \
    { 0xb2, 0xbc, 0xc7, 0x72, 0x96, 0xd1, 0x46, 0xec }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIDOMSVGCSS2Properties : public nsIDOMCSS2Properties {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMSVGCSS2PROPERTIES_IID)

  /* attribute DOMString clipPath; */
  NS_SCRIPTABLE NS_IMETHOD GetClipPath(nsAString & aClipPath) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetClipPath(const nsAString & aClipPath) = 0;

  /* attribute DOMString clipRule; */
  NS_SCRIPTABLE NS_IMETHOD GetClipRule(nsAString & aClipRule) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetClipRule(const nsAString & aClipRule) = 0;

  /* attribute DOMString colorInterpolation; */
  NS_SCRIPTABLE NS_IMETHOD GetColorInterpolation(nsAString & aColorInterpolation) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetColorInterpolation(const nsAString & aColorInterpolation) = 0;

  /* attribute DOMString colorInterpolationFilters; */
  NS_SCRIPTABLE NS_IMETHOD GetColorInterpolationFilters(nsAString & aColorInterpolationFilters) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetColorInterpolationFilters(const nsAString & aColorInterpolationFilters) = 0;

  /* attribute DOMString dominantBaseline; */
  NS_SCRIPTABLE NS_IMETHOD GetDominantBaseline(nsAString & aDominantBaseline) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetDominantBaseline(const nsAString & aDominantBaseline) = 0;

  /* attribute DOMString fill; */
  NS_SCRIPTABLE NS_IMETHOD GetFill(nsAString & aFill) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetFill(const nsAString & aFill) = 0;

  /* attribute DOMString fillOpacity; */
  NS_SCRIPTABLE NS_IMETHOD GetFillOpacity(nsAString & aFillOpacity) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetFillOpacity(const nsAString & aFillOpacity) = 0;

  /* attribute DOMString fillRule; */
  NS_SCRIPTABLE NS_IMETHOD GetFillRule(nsAString & aFillRule) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetFillRule(const nsAString & aFillRule) = 0;

  /* attribute DOMString filter; */
  NS_SCRIPTABLE NS_IMETHOD GetFilter(nsAString & aFilter) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetFilter(const nsAString & aFilter) = 0;

  /* attribute DOMString floodColor; */
  NS_SCRIPTABLE NS_IMETHOD GetFloodColor(nsAString & aFloodColor) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetFloodColor(const nsAString & aFloodColor) = 0;

  /* attribute DOMString floodOpacity; */
  NS_SCRIPTABLE NS_IMETHOD GetFloodOpacity(nsAString & aFloodOpacity) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetFloodOpacity(const nsAString & aFloodOpacity) = 0;

  /* attribute DOMString imageRendering; */
  NS_SCRIPTABLE NS_IMETHOD GetImageRendering(nsAString & aImageRendering) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetImageRendering(const nsAString & aImageRendering) = 0;

  /* attribute DOMString lightingColor; */
  NS_SCRIPTABLE NS_IMETHOD GetLightingColor(nsAString & aLightingColor) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetLightingColor(const nsAString & aLightingColor) = 0;

  /* attribute DOMString marker; */
  NS_SCRIPTABLE NS_IMETHOD GetMarker(nsAString & aMarker) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMarker(const nsAString & aMarker) = 0;

  /* attribute DOMString markerEnd; */
  NS_SCRIPTABLE NS_IMETHOD GetMarkerEnd(nsAString & aMarkerEnd) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMarkerEnd(const nsAString & aMarkerEnd) = 0;

  /* attribute DOMString markerMid; */
  NS_SCRIPTABLE NS_IMETHOD GetMarkerMid(nsAString & aMarkerMid) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMarkerMid(const nsAString & aMarkerMid) = 0;

  /* attribute DOMString markerStart; */
  NS_SCRIPTABLE NS_IMETHOD GetMarkerStart(nsAString & aMarkerStart) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMarkerStart(const nsAString & aMarkerStart) = 0;

  /* attribute DOMString mask; */
  NS_SCRIPTABLE NS_IMETHOD GetMask(nsAString & aMask) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMask(const nsAString & aMask) = 0;

  /* attribute DOMString shapeRendering; */
  NS_SCRIPTABLE NS_IMETHOD GetShapeRendering(nsAString & aShapeRendering) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetShapeRendering(const nsAString & aShapeRendering) = 0;

  /* attribute DOMString stopColor; */
  NS_SCRIPTABLE NS_IMETHOD GetStopColor(nsAString & aStopColor) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetStopColor(const nsAString & aStopColor) = 0;

  /* attribute DOMString stopOpacity; */
  NS_SCRIPTABLE NS_IMETHOD GetStopOpacity(nsAString & aStopOpacity) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetStopOpacity(const nsAString & aStopOpacity) = 0;

  /* attribute DOMString stroke; */
  NS_SCRIPTABLE NS_IMETHOD GetStroke(nsAString & aStroke) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetStroke(const nsAString & aStroke) = 0;

  /* attribute DOMString strokeDasharray; */
  NS_SCRIPTABLE NS_IMETHOD GetStrokeDasharray(nsAString & aStrokeDasharray) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetStrokeDasharray(const nsAString & aStrokeDasharray) = 0;

  /* attribute DOMString strokeDashoffset; */
  NS_SCRIPTABLE NS_IMETHOD GetStrokeDashoffset(nsAString & aStrokeDashoffset) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetStrokeDashoffset(const nsAString & aStrokeDashoffset) = 0;

  /* attribute DOMString strokeLinecap; */
  NS_SCRIPTABLE NS_IMETHOD GetStrokeLinecap(nsAString & aStrokeLinecap) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetStrokeLinecap(const nsAString & aStrokeLinecap) = 0;

  /* attribute DOMString strokeLinejoin; */
  NS_SCRIPTABLE NS_IMETHOD GetStrokeLinejoin(nsAString & aStrokeLinejoin) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetStrokeLinejoin(const nsAString & aStrokeLinejoin) = 0;

  /* attribute DOMString strokeMiterlimit; */
  NS_SCRIPTABLE NS_IMETHOD GetStrokeMiterlimit(nsAString & aStrokeMiterlimit) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetStrokeMiterlimit(const nsAString & aStrokeMiterlimit) = 0;

  /* attribute DOMString strokeOpacity; */
  NS_SCRIPTABLE NS_IMETHOD GetStrokeOpacity(nsAString & aStrokeOpacity) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetStrokeOpacity(const nsAString & aStrokeOpacity) = 0;

  /* attribute DOMString strokeWidth; */
  NS_SCRIPTABLE NS_IMETHOD GetStrokeWidth(nsAString & aStrokeWidth) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetStrokeWidth(const nsAString & aStrokeWidth) = 0;

  /* attribute DOMString textAnchor; */
  NS_SCRIPTABLE NS_IMETHOD GetTextAnchor(nsAString & aTextAnchor) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetTextAnchor(const nsAString & aTextAnchor) = 0;

  /* attribute DOMString textRendering; */
  NS_SCRIPTABLE NS_IMETHOD GetTextRendering(nsAString & aTextRendering) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetTextRendering(const nsAString & aTextRendering) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMSVGCSS2Properties, NS_IDOMSVGCSS2PROPERTIES_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMSVGCSS2PROPERTIES \
  NS_SCRIPTABLE NS_IMETHOD GetClipPath(nsAString & aClipPath); \
  NS_SCRIPTABLE NS_IMETHOD SetClipPath(const nsAString & aClipPath); \
  NS_SCRIPTABLE NS_IMETHOD GetClipRule(nsAString & aClipRule); \
  NS_SCRIPTABLE NS_IMETHOD SetClipRule(const nsAString & aClipRule); \
  NS_SCRIPTABLE NS_IMETHOD GetColorInterpolation(nsAString & aColorInterpolation); \
  NS_SCRIPTABLE NS_IMETHOD SetColorInterpolation(const nsAString & aColorInterpolation); \
  NS_SCRIPTABLE NS_IMETHOD GetColorInterpolationFilters(nsAString & aColorInterpolationFilters); \
  NS_SCRIPTABLE NS_IMETHOD SetColorInterpolationFilters(const nsAString & aColorInterpolationFilters); \
  NS_SCRIPTABLE NS_IMETHOD GetDominantBaseline(nsAString & aDominantBaseline); \
  NS_SCRIPTABLE NS_IMETHOD SetDominantBaseline(const nsAString & aDominantBaseline); \
  NS_SCRIPTABLE NS_IMETHOD GetFill(nsAString & aFill); \
  NS_SCRIPTABLE NS_IMETHOD SetFill(const nsAString & aFill); \
  NS_SCRIPTABLE NS_IMETHOD GetFillOpacity(nsAString & aFillOpacity); \
  NS_SCRIPTABLE NS_IMETHOD SetFillOpacity(const nsAString & aFillOpacity); \
  NS_SCRIPTABLE NS_IMETHOD GetFillRule(nsAString & aFillRule); \
  NS_SCRIPTABLE NS_IMETHOD SetFillRule(const nsAString & aFillRule); \
  NS_SCRIPTABLE NS_IMETHOD GetFilter(nsAString & aFilter); \
  NS_SCRIPTABLE NS_IMETHOD SetFilter(const nsAString & aFilter); \
  NS_SCRIPTABLE NS_IMETHOD GetFloodColor(nsAString & aFloodColor); \
  NS_SCRIPTABLE NS_IMETHOD SetFloodColor(const nsAString & aFloodColor); \
  NS_SCRIPTABLE NS_IMETHOD GetFloodOpacity(nsAString & aFloodOpacity); \
  NS_SCRIPTABLE NS_IMETHOD SetFloodOpacity(const nsAString & aFloodOpacity); \
  NS_SCRIPTABLE NS_IMETHOD GetImageRendering(nsAString & aImageRendering); \
  NS_SCRIPTABLE NS_IMETHOD SetImageRendering(const nsAString & aImageRendering); \
  NS_SCRIPTABLE NS_IMETHOD GetLightingColor(nsAString & aLightingColor); \
  NS_SCRIPTABLE NS_IMETHOD SetLightingColor(const nsAString & aLightingColor); \
  NS_SCRIPTABLE NS_IMETHOD GetMarker(nsAString & aMarker); \
  NS_SCRIPTABLE NS_IMETHOD SetMarker(const nsAString & aMarker); \
  NS_SCRIPTABLE NS_IMETHOD GetMarkerEnd(nsAString & aMarkerEnd); \
  NS_SCRIPTABLE NS_IMETHOD SetMarkerEnd(const nsAString & aMarkerEnd); \
  NS_SCRIPTABLE NS_IMETHOD GetMarkerMid(nsAString & aMarkerMid); \
  NS_SCRIPTABLE NS_IMETHOD SetMarkerMid(const nsAString & aMarkerMid); \
  NS_SCRIPTABLE NS_IMETHOD GetMarkerStart(nsAString & aMarkerStart); \
  NS_SCRIPTABLE NS_IMETHOD SetMarkerStart(const nsAString & aMarkerStart); \
  NS_SCRIPTABLE NS_IMETHOD GetMask(nsAString & aMask); \
  NS_SCRIPTABLE NS_IMETHOD SetMask(const nsAString & aMask); \
  NS_SCRIPTABLE NS_IMETHOD GetShapeRendering(nsAString & aShapeRendering); \
  NS_SCRIPTABLE NS_IMETHOD SetShapeRendering(const nsAString & aShapeRendering); \
  NS_SCRIPTABLE NS_IMETHOD GetStopColor(nsAString & aStopColor); \
  NS_SCRIPTABLE NS_IMETHOD SetStopColor(const nsAString & aStopColor); \
  NS_SCRIPTABLE NS_IMETHOD GetStopOpacity(nsAString & aStopOpacity); \
  NS_SCRIPTABLE NS_IMETHOD SetStopOpacity(const nsAString & aStopOpacity); \
  NS_SCRIPTABLE NS_IMETHOD GetStroke(nsAString & aStroke); \
  NS_SCRIPTABLE NS_IMETHOD SetStroke(const nsAString & aStroke); \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeDasharray(nsAString & aStrokeDasharray); \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeDasharray(const nsAString & aStrokeDasharray); \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeDashoffset(nsAString & aStrokeDashoffset); \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeDashoffset(const nsAString & aStrokeDashoffset); \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeLinecap(nsAString & aStrokeLinecap); \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeLinecap(const nsAString & aStrokeLinecap); \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeLinejoin(nsAString & aStrokeLinejoin); \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeLinejoin(const nsAString & aStrokeLinejoin); \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeMiterlimit(nsAString & aStrokeMiterlimit); \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeMiterlimit(const nsAString & aStrokeMiterlimit); \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeOpacity(nsAString & aStrokeOpacity); \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeOpacity(const nsAString & aStrokeOpacity); \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeWidth(nsAString & aStrokeWidth); \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeWidth(const nsAString & aStrokeWidth); \
  NS_SCRIPTABLE NS_IMETHOD GetTextAnchor(nsAString & aTextAnchor); \
  NS_SCRIPTABLE NS_IMETHOD SetTextAnchor(const nsAString & aTextAnchor); \
  NS_SCRIPTABLE NS_IMETHOD GetTextRendering(nsAString & aTextRendering); \
  NS_SCRIPTABLE NS_IMETHOD SetTextRendering(const nsAString & aTextRendering); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMSVGCSS2PROPERTIES(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetClipPath(nsAString & aClipPath) { return _to GetClipPath(aClipPath); } \
  NS_SCRIPTABLE NS_IMETHOD SetClipPath(const nsAString & aClipPath) { return _to SetClipPath(aClipPath); } \
  NS_SCRIPTABLE NS_IMETHOD GetClipRule(nsAString & aClipRule) { return _to GetClipRule(aClipRule); } \
  NS_SCRIPTABLE NS_IMETHOD SetClipRule(const nsAString & aClipRule) { return _to SetClipRule(aClipRule); } \
  NS_SCRIPTABLE NS_IMETHOD GetColorInterpolation(nsAString & aColorInterpolation) { return _to GetColorInterpolation(aColorInterpolation); } \
  NS_SCRIPTABLE NS_IMETHOD SetColorInterpolation(const nsAString & aColorInterpolation) { return _to SetColorInterpolation(aColorInterpolation); } \
  NS_SCRIPTABLE NS_IMETHOD GetColorInterpolationFilters(nsAString & aColorInterpolationFilters) { return _to GetColorInterpolationFilters(aColorInterpolationFilters); } \
  NS_SCRIPTABLE NS_IMETHOD SetColorInterpolationFilters(const nsAString & aColorInterpolationFilters) { return _to SetColorInterpolationFilters(aColorInterpolationFilters); } \
  NS_SCRIPTABLE NS_IMETHOD GetDominantBaseline(nsAString & aDominantBaseline) { return _to GetDominantBaseline(aDominantBaseline); } \
  NS_SCRIPTABLE NS_IMETHOD SetDominantBaseline(const nsAString & aDominantBaseline) { return _to SetDominantBaseline(aDominantBaseline); } \
  NS_SCRIPTABLE NS_IMETHOD GetFill(nsAString & aFill) { return _to GetFill(aFill); } \
  NS_SCRIPTABLE NS_IMETHOD SetFill(const nsAString & aFill) { return _to SetFill(aFill); } \
  NS_SCRIPTABLE NS_IMETHOD GetFillOpacity(nsAString & aFillOpacity) { return _to GetFillOpacity(aFillOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetFillOpacity(const nsAString & aFillOpacity) { return _to SetFillOpacity(aFillOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetFillRule(nsAString & aFillRule) { return _to GetFillRule(aFillRule); } \
  NS_SCRIPTABLE NS_IMETHOD SetFillRule(const nsAString & aFillRule) { return _to SetFillRule(aFillRule); } \
  NS_SCRIPTABLE NS_IMETHOD GetFilter(nsAString & aFilter) { return _to GetFilter(aFilter); } \
  NS_SCRIPTABLE NS_IMETHOD SetFilter(const nsAString & aFilter) { return _to SetFilter(aFilter); } \
  NS_SCRIPTABLE NS_IMETHOD GetFloodColor(nsAString & aFloodColor) { return _to GetFloodColor(aFloodColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetFloodColor(const nsAString & aFloodColor) { return _to SetFloodColor(aFloodColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetFloodOpacity(nsAString & aFloodOpacity) { return _to GetFloodOpacity(aFloodOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetFloodOpacity(const nsAString & aFloodOpacity) { return _to SetFloodOpacity(aFloodOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetImageRendering(nsAString & aImageRendering) { return _to GetImageRendering(aImageRendering); } \
  NS_SCRIPTABLE NS_IMETHOD SetImageRendering(const nsAString & aImageRendering) { return _to SetImageRendering(aImageRendering); } \
  NS_SCRIPTABLE NS_IMETHOD GetLightingColor(nsAString & aLightingColor) { return _to GetLightingColor(aLightingColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetLightingColor(const nsAString & aLightingColor) { return _to SetLightingColor(aLightingColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetMarker(nsAString & aMarker) { return _to GetMarker(aMarker); } \
  NS_SCRIPTABLE NS_IMETHOD SetMarker(const nsAString & aMarker) { return _to SetMarker(aMarker); } \
  NS_SCRIPTABLE NS_IMETHOD GetMarkerEnd(nsAString & aMarkerEnd) { return _to GetMarkerEnd(aMarkerEnd); } \
  NS_SCRIPTABLE NS_IMETHOD SetMarkerEnd(const nsAString & aMarkerEnd) { return _to SetMarkerEnd(aMarkerEnd); } \
  NS_SCRIPTABLE NS_IMETHOD GetMarkerMid(nsAString & aMarkerMid) { return _to GetMarkerMid(aMarkerMid); } \
  NS_SCRIPTABLE NS_IMETHOD SetMarkerMid(const nsAString & aMarkerMid) { return _to SetMarkerMid(aMarkerMid); } \
  NS_SCRIPTABLE NS_IMETHOD GetMarkerStart(nsAString & aMarkerStart) { return _to GetMarkerStart(aMarkerStart); } \
  NS_SCRIPTABLE NS_IMETHOD SetMarkerStart(const nsAString & aMarkerStart) { return _to SetMarkerStart(aMarkerStart); } \
  NS_SCRIPTABLE NS_IMETHOD GetMask(nsAString & aMask) { return _to GetMask(aMask); } \
  NS_SCRIPTABLE NS_IMETHOD SetMask(const nsAString & aMask) { return _to SetMask(aMask); } \
  NS_SCRIPTABLE NS_IMETHOD GetShapeRendering(nsAString & aShapeRendering) { return _to GetShapeRendering(aShapeRendering); } \
  NS_SCRIPTABLE NS_IMETHOD SetShapeRendering(const nsAString & aShapeRendering) { return _to SetShapeRendering(aShapeRendering); } \
  NS_SCRIPTABLE NS_IMETHOD GetStopColor(nsAString & aStopColor) { return _to GetStopColor(aStopColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetStopColor(const nsAString & aStopColor) { return _to SetStopColor(aStopColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetStopOpacity(nsAString & aStopOpacity) { return _to GetStopOpacity(aStopOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetStopOpacity(const nsAString & aStopOpacity) { return _to SetStopOpacity(aStopOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetStroke(nsAString & aStroke) { return _to GetStroke(aStroke); } \
  NS_SCRIPTABLE NS_IMETHOD SetStroke(const nsAString & aStroke) { return _to SetStroke(aStroke); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeDasharray(nsAString & aStrokeDasharray) { return _to GetStrokeDasharray(aStrokeDasharray); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeDasharray(const nsAString & aStrokeDasharray) { return _to SetStrokeDasharray(aStrokeDasharray); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeDashoffset(nsAString & aStrokeDashoffset) { return _to GetStrokeDashoffset(aStrokeDashoffset); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeDashoffset(const nsAString & aStrokeDashoffset) { return _to SetStrokeDashoffset(aStrokeDashoffset); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeLinecap(nsAString & aStrokeLinecap) { return _to GetStrokeLinecap(aStrokeLinecap); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeLinecap(const nsAString & aStrokeLinecap) { return _to SetStrokeLinecap(aStrokeLinecap); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeLinejoin(nsAString & aStrokeLinejoin) { return _to GetStrokeLinejoin(aStrokeLinejoin); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeLinejoin(const nsAString & aStrokeLinejoin) { return _to SetStrokeLinejoin(aStrokeLinejoin); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeMiterlimit(nsAString & aStrokeMiterlimit) { return _to GetStrokeMiterlimit(aStrokeMiterlimit); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeMiterlimit(const nsAString & aStrokeMiterlimit) { return _to SetStrokeMiterlimit(aStrokeMiterlimit); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeOpacity(nsAString & aStrokeOpacity) { return _to GetStrokeOpacity(aStrokeOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeOpacity(const nsAString & aStrokeOpacity) { return _to SetStrokeOpacity(aStrokeOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeWidth(nsAString & aStrokeWidth) { return _to GetStrokeWidth(aStrokeWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeWidth(const nsAString & aStrokeWidth) { return _to SetStrokeWidth(aStrokeWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetTextAnchor(nsAString & aTextAnchor) { return _to GetTextAnchor(aTextAnchor); } \
  NS_SCRIPTABLE NS_IMETHOD SetTextAnchor(const nsAString & aTextAnchor) { return _to SetTextAnchor(aTextAnchor); } \
  NS_SCRIPTABLE NS_IMETHOD GetTextRendering(nsAString & aTextRendering) { return _to GetTextRendering(aTextRendering); } \
  NS_SCRIPTABLE NS_IMETHOD SetTextRendering(const nsAString & aTextRendering) { return _to SetTextRendering(aTextRendering); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMSVGCSS2PROPERTIES(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetClipPath(nsAString & aClipPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetClipPath(aClipPath); } \
  NS_SCRIPTABLE NS_IMETHOD SetClipPath(const nsAString & aClipPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetClipPath(aClipPath); } \
  NS_SCRIPTABLE NS_IMETHOD GetClipRule(nsAString & aClipRule) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetClipRule(aClipRule); } \
  NS_SCRIPTABLE NS_IMETHOD SetClipRule(const nsAString & aClipRule) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetClipRule(aClipRule); } \
  NS_SCRIPTABLE NS_IMETHOD GetColorInterpolation(nsAString & aColorInterpolation) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetColorInterpolation(aColorInterpolation); } \
  NS_SCRIPTABLE NS_IMETHOD SetColorInterpolation(const nsAString & aColorInterpolation) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetColorInterpolation(aColorInterpolation); } \
  NS_SCRIPTABLE NS_IMETHOD GetColorInterpolationFilters(nsAString & aColorInterpolationFilters) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetColorInterpolationFilters(aColorInterpolationFilters); } \
  NS_SCRIPTABLE NS_IMETHOD SetColorInterpolationFilters(const nsAString & aColorInterpolationFilters) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetColorInterpolationFilters(aColorInterpolationFilters); } \
  NS_SCRIPTABLE NS_IMETHOD GetDominantBaseline(nsAString & aDominantBaseline) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDominantBaseline(aDominantBaseline); } \
  NS_SCRIPTABLE NS_IMETHOD SetDominantBaseline(const nsAString & aDominantBaseline) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDominantBaseline(aDominantBaseline); } \
  NS_SCRIPTABLE NS_IMETHOD GetFill(nsAString & aFill) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFill(aFill); } \
  NS_SCRIPTABLE NS_IMETHOD SetFill(const nsAString & aFill) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFill(aFill); } \
  NS_SCRIPTABLE NS_IMETHOD GetFillOpacity(nsAString & aFillOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFillOpacity(aFillOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetFillOpacity(const nsAString & aFillOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFillOpacity(aFillOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetFillRule(nsAString & aFillRule) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFillRule(aFillRule); } \
  NS_SCRIPTABLE NS_IMETHOD SetFillRule(const nsAString & aFillRule) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFillRule(aFillRule); } \
  NS_SCRIPTABLE NS_IMETHOD GetFilter(nsAString & aFilter) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFilter(aFilter); } \
  NS_SCRIPTABLE NS_IMETHOD SetFilter(const nsAString & aFilter) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFilter(aFilter); } \
  NS_SCRIPTABLE NS_IMETHOD GetFloodColor(nsAString & aFloodColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFloodColor(aFloodColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetFloodColor(const nsAString & aFloodColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFloodColor(aFloodColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetFloodOpacity(nsAString & aFloodOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFloodOpacity(aFloodOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetFloodOpacity(const nsAString & aFloodOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFloodOpacity(aFloodOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetImageRendering(nsAString & aImageRendering) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImageRendering(aImageRendering); } \
  NS_SCRIPTABLE NS_IMETHOD SetImageRendering(const nsAString & aImageRendering) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImageRendering(aImageRendering); } \
  NS_SCRIPTABLE NS_IMETHOD GetLightingColor(nsAString & aLightingColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLightingColor(aLightingColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetLightingColor(const nsAString & aLightingColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetLightingColor(aLightingColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetMarker(nsAString & aMarker) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMarker(aMarker); } \
  NS_SCRIPTABLE NS_IMETHOD SetMarker(const nsAString & aMarker) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMarker(aMarker); } \
  NS_SCRIPTABLE NS_IMETHOD GetMarkerEnd(nsAString & aMarkerEnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMarkerEnd(aMarkerEnd); } \
  NS_SCRIPTABLE NS_IMETHOD SetMarkerEnd(const nsAString & aMarkerEnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMarkerEnd(aMarkerEnd); } \
  NS_SCRIPTABLE NS_IMETHOD GetMarkerMid(nsAString & aMarkerMid) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMarkerMid(aMarkerMid); } \
  NS_SCRIPTABLE NS_IMETHOD SetMarkerMid(const nsAString & aMarkerMid) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMarkerMid(aMarkerMid); } \
  NS_SCRIPTABLE NS_IMETHOD GetMarkerStart(nsAString & aMarkerStart) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMarkerStart(aMarkerStart); } \
  NS_SCRIPTABLE NS_IMETHOD SetMarkerStart(const nsAString & aMarkerStart) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMarkerStart(aMarkerStart); } \
  NS_SCRIPTABLE NS_IMETHOD GetMask(nsAString & aMask) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMask(aMask); } \
  NS_SCRIPTABLE NS_IMETHOD SetMask(const nsAString & aMask) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMask(aMask); } \
  NS_SCRIPTABLE NS_IMETHOD GetShapeRendering(nsAString & aShapeRendering) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetShapeRendering(aShapeRendering); } \
  NS_SCRIPTABLE NS_IMETHOD SetShapeRendering(const nsAString & aShapeRendering) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetShapeRendering(aShapeRendering); } \
  NS_SCRIPTABLE NS_IMETHOD GetStopColor(nsAString & aStopColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStopColor(aStopColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetStopColor(const nsAString & aStopColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStopColor(aStopColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetStopOpacity(nsAString & aStopOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStopOpacity(aStopOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetStopOpacity(const nsAString & aStopOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStopOpacity(aStopOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetStroke(nsAString & aStroke) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStroke(aStroke); } \
  NS_SCRIPTABLE NS_IMETHOD SetStroke(const nsAString & aStroke) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStroke(aStroke); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeDasharray(nsAString & aStrokeDasharray) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStrokeDasharray(aStrokeDasharray); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeDasharray(const nsAString & aStrokeDasharray) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStrokeDasharray(aStrokeDasharray); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeDashoffset(nsAString & aStrokeDashoffset) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStrokeDashoffset(aStrokeDashoffset); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeDashoffset(const nsAString & aStrokeDashoffset) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStrokeDashoffset(aStrokeDashoffset); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeLinecap(nsAString & aStrokeLinecap) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStrokeLinecap(aStrokeLinecap); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeLinecap(const nsAString & aStrokeLinecap) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStrokeLinecap(aStrokeLinecap); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeLinejoin(nsAString & aStrokeLinejoin) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStrokeLinejoin(aStrokeLinejoin); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeLinejoin(const nsAString & aStrokeLinejoin) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStrokeLinejoin(aStrokeLinejoin); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeMiterlimit(nsAString & aStrokeMiterlimit) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStrokeMiterlimit(aStrokeMiterlimit); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeMiterlimit(const nsAString & aStrokeMiterlimit) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStrokeMiterlimit(aStrokeMiterlimit); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeOpacity(nsAString & aStrokeOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStrokeOpacity(aStrokeOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeOpacity(const nsAString & aStrokeOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStrokeOpacity(aStrokeOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetStrokeWidth(nsAString & aStrokeWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStrokeWidth(aStrokeWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetStrokeWidth(const nsAString & aStrokeWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStrokeWidth(aStrokeWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetTextAnchor(nsAString & aTextAnchor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTextAnchor(aTextAnchor); } \
  NS_SCRIPTABLE NS_IMETHOD SetTextAnchor(const nsAString & aTextAnchor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetTextAnchor(aTextAnchor); } \
  NS_SCRIPTABLE NS_IMETHOD GetTextRendering(nsAString & aTextRendering) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTextRendering(aTextRendering); } \
  NS_SCRIPTABLE NS_IMETHOD SetTextRendering(const nsAString & aTextRendering) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetTextRendering(aTextRendering); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMSVGCSS2Properties : public nsIDOMSVGCSS2Properties
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMSVGCSS2PROPERTIES

  nsDOMSVGCSS2Properties();

private:
  ~nsDOMSVGCSS2Properties();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMSVGCSS2Properties, nsIDOMSVGCSS2Properties)

nsDOMSVGCSS2Properties::nsDOMSVGCSS2Properties()
{
  /* member initializers and constructor code */
}

nsDOMSVGCSS2Properties::~nsDOMSVGCSS2Properties()
{
  /* destructor code */
}

/* attribute DOMString clipPath; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetClipPath(nsAString & aClipPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetClipPath(const nsAString & aClipPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString clipRule; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetClipRule(nsAString & aClipRule)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetClipRule(const nsAString & aClipRule)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString colorInterpolation; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetColorInterpolation(nsAString & aColorInterpolation)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetColorInterpolation(const nsAString & aColorInterpolation)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString colorInterpolationFilters; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetColorInterpolationFilters(nsAString & aColorInterpolationFilters)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetColorInterpolationFilters(const nsAString & aColorInterpolationFilters)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString dominantBaseline; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetDominantBaseline(nsAString & aDominantBaseline)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetDominantBaseline(const nsAString & aDominantBaseline)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString fill; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetFill(nsAString & aFill)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetFill(const nsAString & aFill)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString fillOpacity; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetFillOpacity(nsAString & aFillOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetFillOpacity(const nsAString & aFillOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString fillRule; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetFillRule(nsAString & aFillRule)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetFillRule(const nsAString & aFillRule)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString filter; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetFilter(nsAString & aFilter)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetFilter(const nsAString & aFilter)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString floodColor; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetFloodColor(nsAString & aFloodColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetFloodColor(const nsAString & aFloodColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString floodOpacity; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetFloodOpacity(nsAString & aFloodOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetFloodOpacity(const nsAString & aFloodOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString imageRendering; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetImageRendering(nsAString & aImageRendering)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetImageRendering(const nsAString & aImageRendering)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString lightingColor; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetLightingColor(nsAString & aLightingColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetLightingColor(const nsAString & aLightingColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString marker; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetMarker(nsAString & aMarker)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetMarker(const nsAString & aMarker)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString markerEnd; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetMarkerEnd(nsAString & aMarkerEnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetMarkerEnd(const nsAString & aMarkerEnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString markerMid; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetMarkerMid(nsAString & aMarkerMid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetMarkerMid(const nsAString & aMarkerMid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString markerStart; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetMarkerStart(nsAString & aMarkerStart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetMarkerStart(const nsAString & aMarkerStart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString mask; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetMask(nsAString & aMask)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetMask(const nsAString & aMask)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString shapeRendering; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetShapeRendering(nsAString & aShapeRendering)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetShapeRendering(const nsAString & aShapeRendering)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString stopColor; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetStopColor(nsAString & aStopColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetStopColor(const nsAString & aStopColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString stopOpacity; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetStopOpacity(nsAString & aStopOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetStopOpacity(const nsAString & aStopOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString stroke; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetStroke(nsAString & aStroke)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetStroke(const nsAString & aStroke)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString strokeDasharray; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetStrokeDasharray(nsAString & aStrokeDasharray)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetStrokeDasharray(const nsAString & aStrokeDasharray)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString strokeDashoffset; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetStrokeDashoffset(nsAString & aStrokeDashoffset)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetStrokeDashoffset(const nsAString & aStrokeDashoffset)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString strokeLinecap; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetStrokeLinecap(nsAString & aStrokeLinecap)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetStrokeLinecap(const nsAString & aStrokeLinecap)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString strokeLinejoin; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetStrokeLinejoin(nsAString & aStrokeLinejoin)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetStrokeLinejoin(const nsAString & aStrokeLinejoin)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString strokeMiterlimit; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetStrokeMiterlimit(nsAString & aStrokeMiterlimit)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetStrokeMiterlimit(const nsAString & aStrokeMiterlimit)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString strokeOpacity; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetStrokeOpacity(nsAString & aStrokeOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetStrokeOpacity(const nsAString & aStrokeOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString strokeWidth; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetStrokeWidth(nsAString & aStrokeWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetStrokeWidth(const nsAString & aStrokeWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString textAnchor; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetTextAnchor(nsAString & aTextAnchor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetTextAnchor(const nsAString & aTextAnchor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString textRendering; */
NS_IMETHODIMP nsDOMSVGCSS2Properties::GetTextRendering(nsAString & aTextRendering)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMSVGCSS2Properties::SetTextRendering(const nsAString & aTextRendering)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMSVGCSS2Properties_h__ */
